@@ -3,7 +3,6 @@ from unittest import TestCase
 
 import pytest
 from lexicon.tests.providers.integration_tests import IntegrationTests
-from lexicon.providers.localzone import Provider
 
 try:
     from urllib.request import urlretrieve
@@ -16,7 +15,6 @@ except ImportError:
 # pass, by inheritance from define_tests.TheTests
 class LocalzoneProviderTests(TestCase, IntegrationTests):
     """Integration tests for Localzone"""
-    Provider = Provider
     provider_name = "localzone"
     domain = "example.com"
     file_uri = "https://raw.githubusercontent.com/ags-slc/localzone/master/tests/zonefiles/db.example.com"  # pylint: disable=line-too-long
